==> qtjambi-xml-5.15.6-sources.jar: io/qt/xml/QXmlLexicalHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report the lexical content of XML data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html">QXmlLexicalHandler</a></p>
 */
@Deprecated
public interface QXmlLexicalHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlLexicalHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlLexicalHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlLexicalHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean comment(java.lang.String ch){
                return comment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), ch);
            }
            private native static boolean comment_native_cref_QString(long __this__nativeId, java.lang.String ch);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endCDATA(){
                return endCDATA_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean endCDATA_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endDTD(){
                return endDTD_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean endDTD_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endEntity(java.lang.String name){
                return endEntity_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static boolean endEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startCDATA(){
                return startCDATA_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean startCDATA_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId){
                return startDTD_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId);
            }
            private native static boolean startDTD_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startEntity(java.lang.String name){
                return startEntity_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static boolean startEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlLexicalHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#comment">QXmlLexicalHandler::comment(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean comment(java.lang.String ch);
        
        private native static boolean comment_native_cref_QString(long __this__nativeId, java.lang.String ch);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endCDATA">QXmlLexicalHandler::endCDATA()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endCDATA();
        
        private native static boolean endCDATA_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endDTD">QXmlLexicalHandler::endDTD()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endDTD();
        
        private native static boolean endDTD_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endEntity">QXmlLexicalHandler::endEntity(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endEntity(java.lang.String name);
        
        private native static boolean endEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#errorString">QXmlLexicalHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startCDATA">QXmlLexicalHandler::startCDATA()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startCDATA();
        
        private native static boolean startCDATA_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startDTD">QXmlLexicalHandler::startDTD(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        private native static boolean startDTD_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startEntity">QXmlLexicalHandler::startEntity(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startEntity(java.lang.String name);
        
        private native static boolean startEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#comment">QXmlLexicalHandler::comment(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean comment(java.lang.String ch);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endCDATA">QXmlLexicalHandler::endCDATA()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endCDATA();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endDTD">QXmlLexicalHandler::endDTD()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endDTD();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endEntity">QXmlLexicalHandler::endEntity(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endEntity(java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#errorString">QXmlLexicalHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startCDATA">QXmlLexicalHandler::startCDATA()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startCDATA();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startDTD">QXmlLexicalHandler::startDTD(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startEntity">QXmlLexicalHandler::startEntity(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startEntity(java.lang.String name);
    
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QXmlLexicalHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report the lexical content of XML data</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html">QXmlLexicalHandler</a></p>
 */
@Deprecated
public interface QXmlLexicalHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlLexicalHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlLexicalHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlLexicalHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean comment(java.lang.String ch){
                return comment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), ch);
            }
            private native static boolean comment_native_cref_QString(long __this__nativeId, java.lang.String ch);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endCDATA(){
                return endCDATA_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean endCDATA_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endDTD(){
                return endDTD_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean endDTD_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endEntity(java.lang.String name){
                return endEntity_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static boolean endEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startCDATA(){
                return startCDATA_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean startCDATA_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId){
                return startDTD_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId);
            }
            private native static boolean startDTD_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startEntity(java.lang.String name){
                return startEntity_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static boolean startEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlLexicalHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#comment">QXmlLexicalHandler::comment(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean comment(java.lang.String ch);
        
        private native static boolean comment_native_cref_QString(long __this__nativeId, java.lang.String ch);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endCDATA">QXmlLexicalHandler::endCDATA()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endCDATA();
        
        private native static boolean endCDATA_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endDTD">QXmlLexicalHandler::endDTD()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endDTD();
        
        private native static boolean endDTD_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endEntity">QXmlLexicalHandler::endEntity(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endEntity(java.lang.String name);
        
        private native static boolean endEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#errorString">QXmlLexicalHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startCDATA">QXmlLexicalHandler::startCDATA()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startCDATA();
        
        private native static boolean startCDATA_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startDTD">QXmlLexicalHandler::startDTD(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        private native static boolean startDTD_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startEntity">QXmlLexicalHandler::startEntity(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startEntity(java.lang.String name);
        
        private native static boolean startEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#comment">QXmlLexicalHandler::comment(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean comment(java.lang.String ch);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endCDATA">QXmlLexicalHandler::endCDATA()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endCDATA();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endDTD">QXmlLexicalHandler::endDTD()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endDTD();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#endEntity">QXmlLexicalHandler::endEntity(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endEntity(java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#errorString">QXmlLexicalHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startCDATA">QXmlLexicalHandler::startCDATA()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startCDATA();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startDTD">QXmlLexicalHandler::startDTD(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllexicalhandler.html#startEntity">QXmlLexicalHandler::startEntity(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startEntity(java.lang.String name);
    
}
